pub enum CreateMode {
Copy,
Symlink,
Hardlink,
}Expand description
Strategy used to materialize playground contents into a temporary directory.
Variants
Copy
Recursively copy files into the temporary directory.
Symlink
Create symlinks from the temporary directory back to the playground.
Hardlink
Recreate directories and hard-link regular files into the temporary directory.